@@ -3,6 +3,7 @@ import glob
 import oommfodt
 import micromagneticmodel as mm
 import discretisedfield as df
+import oommfc as oc
 
 
 class Driver(mm.Driver):
@@ -13,21 +14,17 @@ class Driver(mm.Driver):
         """
         filenames = self._filenames(system)
 
-        # Make directory for saving OOMMF files.
+        # Make a directory for saving OOMMF files.
         self._makedir(system)
 
         # Save system's magnetisation configuration omf file.
         omffilename = filenames["omffilename"]
         system.m.write_oommf_file(omffilename)
 
-        # Save OOMMF configuration mif file.
         miffilename = filenames["miffilename"]
         self._save_mif(system, **kwargs)
 
-        # Run simulation.
         self._run_simulator(system)
-
-        # Update system.
         self._update_system(system)
 
     def _makedir(self, system):
@@ -55,16 +52,9 @@ class Driver(mm.Driver):
         dirname = self._filenames(system)["dirname"]
         miffilename = self._filenames(system)["miffilename"]
 
-        if os.name == "nt":
-            oommf_command = ("tclsh86 %OOMMFTCL% "  # pragma: no cover
-                             "boxsi +fg {} -exitondone 1").format(miffilename)
-        else:
-            oommf_command = ("tclsh $OOMMFTCL boxsi +fg {} "
-                             "-exitondone 1").format(miffilename)
-        os.system("cd {}".format(dirname))
-        returncode = os.system(oommf_command)
-        if returncode:
-            raise Exception("Error in running OOMMF")  # pragma: no cover
+        oommf = oc.OOMMF()
+
+        oommf.call_oommf(miffilename)
 
     def _update_system(self, system):
         self._update_m(system)
@@ -77,8 +67,10 @@ class Driver(mm.Driver):
                             key=os.path.getctime)
 
         # Update system's magnetisaton.
-        system.m = df.read_oommf_file(last_omf_file,
-                                      normalisedto=system.m.normalisedto)
+        m_field = df.read_oommf_file(last_omf_file)
+        m_field.normalisedto = system.m.normalisedto
+        m_field.normalise()
+        system.m = m_field
 
     def _update_dt(self, system):
         # Find last odt file.
